from .DataApiQuery import DataApiQuery, SamplingPeriod, REQUEST_LIMIT
from pydantic import root_validator

"""This script contains the class inheriting everything except input/output_sampling 
period from the DataApiQuery class. This is where more specific functionailty 
should be added for the FilterApiQuery endpoint if/when changes need to be made"""


class FilterApiQuery(DataApiQuery):
    input_sampling_period: SamplingPeriod = SamplingPeriod.SECOND
    output_sampling_period: SamplingPeriod = SamplingPeriod.MINUTE

    # Remove inherited fields that we don't need for this specific endpoint
    class Config:
        fields = {"sampling_period": {"exclude": True}}

    @root_validator
    def validate_combinations(cls, values):
        starttime, endtime, elements, format, input_sampling_period = (
            values.get("starttime"),
            values.get("endtime"),
            values.get("elements"),
            values.get("format"),
            values.get("input_sampling_period"),
        )
        if len(elements) > 4 and format == "iaga2002":
            raise ValueError("No more than four elements allowed for iaga2002 format.")
        if starttime > endtime:
            raise ValueError("Starttime must be before endtime.")

        # Calculate the number of samples based on the input sampling period
        samples = int(len(elements) * (endtime - starttime) / input_sampling_period)

        # Validate the request size
        if samples > REQUEST_LIMIT:
            raise ValueError(f"Request exceeds limit ({samples} > {REQUEST_LIMIT})")

        return values
